!**CROP DEVELOPMENT AS SUGGESTED IN WOFOST/SWAP (e.g. van Dam et al. 2002, WUR)
!**modified and simplified approach to be used in WASA (Gntner 2002, PIK)
SUBROUTINE CROPDEVELOP(CROP1,i_subas,lu_counter,tc_counter,evaptpv_svc,evaptv_svc,theta_svc,tc_label,muni,cropout)

use climo_h
use common_h
use hymo_h
use params_h
use time_h

IMPLICIT NONE

REAL,INTENT(INOUT)	:: CROP1(30,subasin,maxsoter,maxterrain,maxsoil)
INTEGER,INTENT(IN)	:: i_subas,lu_counter,tc_counter
REAL, INTENT(IN)		:: theta_svc(maxsoil),evaptpv_svc(maxsoil),evaptv_svc(maxsoil)
INTEGER, INTENT(IN)		:: tc_label,muni
REAL, INTENT(INOUT)		:: cropout(366,6)

INTEGER	:: j,i,vegi,baresoil,TI

!************* DEFINITIONS OF PARAMETERS FROM CROP FILE ****************

!** emergence
REAL :: TBASEM	  ! lower threshold temp. for emergence [cel]
REAL :: TEFFMX	  ! max. eff. temp. for emergence [cel]
REAL :: TSUMEM	  ! temperature sum from sowing to emergence [cel d]
!** phenology
REAL :: IDSL	  ! indicates whether pre-anthesis development depends
							  ! on temp. (=0), daylength (=1) , or both (=2)
REAL :: DLO 	  ! optimum daylength for development [hr]
REAL :: DLC 	  ! critical daylength (lower threshold) [hr]
REAL :: TSUM1	  ! temperature sum from emergence to anthesis [cel d]
REAL :: TSUM2	  ! temperature sum from anthesis to maturity [cel d]
REAL :: DTSMTB(2,6) 	! daily increase in temp. sum 
									! as function of av. temp. [cel; cel d]
REAL :: DVSI	  ! initial DVS
REAL :: DVSEND	  ! development stage at harvest (= 2.0 at maturity [-])
!** initial
REAL :: TDWI	  ! initial total crop dry weight [kg ha-1]
!** ! Not used as imput by WOF6_0 model
REAL :: LAIEM	  ! leaf area index at emergence [ha ha-1]
REAL :: RGRLAI	  ! maximum relative increase in LAI [ha ha-1 d-1]
!** green area
REAL :: SLATB(2,6) ! specific leaf area  
								! as a function of DVS [-; ha kg-1]
REAL :: SPA 	    ! specific pod area [ha kg-1]
REAL :: SSATB(2,2) ! specific stem area [ha kg-1]
								! as function of DVS
REAL :: SPAN	    ! life span of leaves growing at 35 Celsius [d]
REAL :: TBASE	    ! lower threshold temp. for ageing of leaves [cel]
!** assimilation
REAL :: KDIFTB(2,2)   ! extinction coefficient for diffuse visible light [-]
								   ! as function of DVS
REAL :: EFFTB(2,2)	   ! light-use effic. single leaf [kg ha-1 hr-1 J-1 m2 s]
								   ! as function of daily mean temp.
REAL :: AMAXTB(2,6)   ! max. leaf CO2 assim. rate
								   ! function of DVS [-; kg ha-1 hr-1]
REAL :: TMPFTB(2,8)   ! reduction factor of AMAX
								   ! as function of av. temp. [cel; -]
REAL :: TMNFTB(2,2)   ! red. factor of gross assim. rate
								   ! as function of low min. temp. [cel; -]
!** conversion of assimilates into biomass
REAL :: CVL   ! efficiency of conversion into leaves [kg kg-1]
REAL :: CVO   ! efficiency of conversion into storage org. [kg kg-1]
REAL :: CVR   ! efficiency of conversion into roots [kg kg-1]
REAL :: CVS   ! efficiency of conversion into stems [kg kg-1]
!** maintenance respiration
REAL :: Q10   ! rel. incr. in resp. rate per 10 Cel temp. incr. [-]
REAL :: RML   ! rel. maint. resp. rate leaves [kg CH2O kg-1 d-1]
REAL :: RMO   ! rel. maint. resp. rate stor.org. [kg CH2O kg-1 d-1]
REAL :: RMR   ! rel. maint. resp. rate roots [kg CH2O kg-1 d-1]
REAL :: RMS   ! rel. maint. resp. rate stems [kg CH2O kg-1 d-1]
REAL :: RFSETB(2,2)    ! red. factor for senescence
								 	! as function of DVS [-; -]
!** partitioning		
REAL :: FRTB(2,10)	  ! fraction of total dry matter to roots
								  ! as a function of DVS [-; kg kg-1]
REAL :: FLTB(2,10)	  ! fraction of above-gr. DM to leaves
								  ! as a function of DVS [-; kg kg-1]
REAL :: FSTB(2,10)	  ! fraction of above-gr. DM to stems
								  ! as a function of DVS [-; kg kg-1]
REAL :: FOTB(2,10)	  ! fraction of above-gr. DM to stor. org.
								  ! as a function of DVS [-; kg kg-1]
!** death rates
REAL :: PERDL		   ! max. rel. death rate of leaves due to water stress
REAL :: RDRRTB(2,6)   ! rel. death rate of roots 
								   ! as a function of DVS [-; kg kg-1 d-1]
REAL :: RDRSTB(2,6)   ! rel. death rate of stems
								   ! as a function of DVS [-; kg kg-1 d-1]	 
!** water use
REAL :: CFET		  ! correction factor transpiration rate [-]
REAL :: DEPNR		  ! crop group number for soil water depletion [-]
REAL :: IAIRDU		  ! air ducts in roots present (=1) or not (=0)
!** rooting
REAL :: RDI 		  ! initial rooting depth [cm]
REAL :: RRI 		  ! maximum daily increase in rooting depth [cm d-1]
REAL :: RDMCR		  ! maximum rooting depth [cm]
REAL :: GROWMX		  ! maximum height at full developemt stage 1 [cm] *estimated

!** nutrients
!** maximum and minimum concentrations of N, P, and K
!** in storage organs		 in vegetative organs [kg kg-1]
REAL :: NMINSO,NMINVE
REAL :: NMAXSO,NMAXVE
REAL :: PMINSO,PMINVE
REAL :: PMAXSO,PMAXVE
REAL :: KMINSO,KMINVE
REAL :: KMAXSO,KMAXVE
REAL :: YZERO	  ! max. amount veg. organs at zero yield [kg ha-1]
REAL :: NFIX	  ! fraction of N-uptake from biol. fixation [kg kg-1]
!*
!*
!**************** END CROP FILE DEFINITIONS ********************

!do check the read in plant specific parameters for being used in this routine - 
!remove if not to reclaim overview 

REAL :: TEMPEFF,DVRED,AMAX,TAVD,TMINF,GAUSR,DTGA,HOUR,SINB,PARDIR,PARDIF
REAL :: FGROS,PGASS,GASS,WRT,WST,WLV,WSO,GLA,GLASOL,GLAIEX,DTEFF,LAIEXP,SLAT
REAL :: FYSDEL,DSLV,DSLV1,DSLV2,LAICR,GRLV,ADMI,DMI,CVF,MRES,RMRES,TEFF
REAL :: fo,fl,fs,fr,ASRC,GRRT,RDRR,DRRT,GRST,RDRS,DRST,GWSO,RR,TSUM
REAL :: PAR,ATMTR,FRDF
REAL :: mTEMP,wTEMP !mean temperature (min+max)/2; weighted mean (min+3max)/4


!******************  LETS GO  *********

DO i=1,tc_label !loop through all svcs in tc

!debug conrad!
!IF (i_subas==18.AND.lu_counter==2.AND.tc_counter==5.AND.i==4.AND. d>192 .AND.t==1992) THEN
!	write(*,*)'wake up - showtime!'
!END IF

!>open crop parameters
 vegi=INT(CROP1(5,i_subas,lu_counter,tc_counter,i))
 CALL cropfile (vegi,TBASEM,TEFFMX,TSUMEM,IDSL,DLO,DLC,TSUM1,TSUM2, &
					 DTSMTB,DVSI,DVSEND,TDWI,LAIEM,RGRLAI,SLATB,SPA,SSATB,SPAN,TBASE,KDIFTB,EFFTB,AMAXTB,TMPFTB, &
					 TMNFTB,CVL,CVO,CVR,CVS,Q10,RML,RMO,RMR,RMS,RFSETB,FRTB,FLTB,FSTB,FOTB,PERDL,RDRRTB,RDRSTB, &
					 CFET,DEPNR,IAIRDU,RDI,RRI,RDMCR,NMINSO,NMINVE,NMAXSO,NMAXVE,PMINSO,PMINVE,PMAXSO,PMAXVE, &
					 KMINSO,KMINVE,KMAXSO,KMAXVE,YZERO,NFIX,GROWMX,baresoil)

IF (CROP1(14,i_subas,lu_counter,tc_counter,i)>0.) THEN
!>get effective temperature for crop development

 if (isnan(tmax(d,muni))<1. .AND. isnan(tmin(d,muni))<1.0 .AND. tmin(d,muni)/=16.1 .AND. tmax(d,muni)/=30.0) then			 !only if parameter is given
	mTEMP=(tmax(d,muni)+tmin(d,muni))/2. !mean from tmin+tmax
	wTEMP=(tmax(d,muni)+mTEMP)/2.		 !weighted mean for day tmin+3tmax
 else
	mTEMP=temp(d,muni)
	wTEMP=mTEMP
 end if

 call getparam(tempeff,wTEMP,DTSMTB,6) !get effective temperature

 IF (CROP1(14,i_subas,lu_counter,tc_counter,i)==1.) THEN
 !>stage=1: seed sawn .. emerge

   ! check for maximum temperature exceed *debug: always emerging. no T-limit
   !IF (mTEMP>TEFFMX) THEN
    ! CROP1(14,i_subas,lu_counter,tc_counter,i)=4 !seeds cannot emerge because of too hight temperature
   !END IF
   
   !>development
   IF (CROP1(6,i_subas,lu_counter,tc_counter,i)<1.0.AND.theta_svc(i)<=soilpwp(INT(CROP1(4,i_subas,lu_counter,tc_counter,i)),1)) THEN
   CROP1(7,i_subas,lu_counter,tc_counter,i)=CROP1(7,i_subas,lu_counter,tc_counter,i) !no development of seed at water stress
   ELSE
   CROP1(7,i_subas,lu_counter,tc_counter,i)=CROP1(7,i_subas,lu_counter,tc_counter,i)+(tempeff/(TSUMEM+TSUM1))
   END IF
   CROP1(15,i_subas,lu_counter,tc_counter,i)=CROP1(15,i_subas,lu_counter,tc_counter,i)+tempeff

 ELSE IF (CROP1(14,i_subas,lu_counter,tc_counter,i)==2.0.OR.CROP1(14,i_subas,lu_counter,tc_counter,i)==3.) THEN
 !>stage=2: vegetation/maturity
    
	IF (CROP1(14,i_subas,lu_counter,tc_counter,i)==2.) THEN
    IF (IDSL>=1) THEN !optimal development depends on daylight
		dvred=MAX(MIN((DAYL(d)-DLC)/(DLO-DLC),1.),0.)
		!>development
   		CROP1(7,i_subas,lu_counter,tc_counter,i)=CROP1(7,i_subas,lu_counter,tc_counter,i)+(dvred*tempeff)/TSUM1
   		CROP1(15,i_subas,lu_counter,tc_counter,i)=CROP1(15,i_subas,lu_counter,tc_counter,i)+(dvred*tempeff)

  	ELSE
    	!>development
   		CROP1(7,i_subas,lu_counter,tc_counter,i)=CROP1(7,i_subas,lu_counter,tc_counter,i)+tempeff/TSUM1
   		CROP1(15,i_subas,lu_counter,tc_counter,i)=CROP1(15,i_subas,lu_counter,tc_counter,i)+tempeff
	END IF
    ELSE
    	!>development
   		CROP1(7,i_subas,lu_counter,tc_counter,i)=CROP1(7,i_subas,lu_counter,tc_counter,i)+tempeff/TSUM2
   		CROP1(15,i_subas,lu_counter,tc_counter,i)=CROP1(15,i_subas,lu_counter,tc_counter,i)+tempeff
    END IF
    
    !>Assimilation procedure
    !>gross assimilation rate: GASS
    call getparam(AMAX,CROP1(7,i_subas,lu_counter,tc_counter,i),AMAXTB,6) ! max. leaf CO2 assim. rate as function of DVS [-; kg ha-1 hr-1]
    call getparam(TAVD,wTEMP,TMPFTB,8) ! reduction factor of AMAX depending on weighted mean temperature
    call getparam(TMINF,tmin(d,muni),TMNFTB,2) !reduction factor of AMAX depending on low minimum temperature on previous 3 days
    
!conrad: debug!!!
TAVD=MAX(TAVD,0.2)
IF (CROP1(15,i_subas,lu_counter,tc_counter,i)<0.) THEN
write(*,*)'trouble in temperature quantum storage'
END IF

    AMAX=AMAX*TAVD*1/36000	!reduction of AMAX in case of sub-optimal temperature
						!convert kg*ha-1*h-1 into g*m-2*s-1 
    
	!>>>total assimilation
    GAUSR=0.3872983
	! ----TOTASS based on WOFOST/SWAP/SUCROS2--

	! --- three point gaussian integration over day
      DTGA  = 0.

      IF (AMAX>0. .AND. CROP1(9,i_subas,lu_counter,tc_counter,i)>0.) THEN !calculation only if AMAX and LAI >0.
      DO TI=1,3
        HOUR = 12.0+DAYL(d)*0.5*(0.5+(TI-2)*GAUSR) !specific hour for radiation at gauss weighted point
		SINB = MAX(0.,SINLD(d)+COSLD(d)*cos(2.*pi*(HOUR+12.)/24.)) !sine of solar elevation
		PAR  = 0.5*S0(d)*SINB*(1.+0.4*SINB)/DSINBE(d) !
		ATMTR= PAR/(0.5*SoC(d)*SINB) !atmospheric transition
		
		IF (ATMTR.LE.0.22) THEN
			FRDF = 1.			 !diffuse light fraction of global radiation
		ELSE IF (ATMTR.GT.0.22 .AND. ATMTR.LE.0.35) THEN
			FRDF = 1.-6.4*(ATMTR-0.22)**2
		ELSE
			FRDF = 1.47-1.66*ATMTR
		END IF
		FRDF=max(FRDF, 0.15+0.85*(1.-exp(-0.1/SINB)))
		PARDIF=PAR*FRDF		!diffuse radiation
		PARDIR=PAR-PARDIF	!direct radiation
	
	! --- irradiance and crop properties determine assimilation
        CALL ASSIM (AMAX,EFFTB(2,1),CROP1(9,i_subas,lu_counter,tc_counter,i),KDIFTB(2,1),SINB,PARDIR,PARDIF,FGROS) 
    
	    IF(TI.EQ.2) FGROS=FGROS*1.6										
        DTGA = DTGA+FGROS
		
      END DO
	  DTGA = DTGA/3.6 !g CO2 / (m2*s)
      END IF
      DTGA  =DTGA*DAYL(d)*3600. !g CO2 /(m2*d)
	! ----END TOTASS-----------------------------------------------
      
      DTGA= DTGA*TMINF !modify daily total gross assimilation
      !POTENTIAL ASSIMILATION (for each kg CO2 30/44 kg biomass (CH2O) is formed)
	  PGASS=DTGA * 30.0/44.0
	  
	  !WATER STRESS LIMITATION AS RATIO OF ACT.TRANSPIRATION/(ETPACT-ETPSOIL)
	  if (evaptpv_svc(i)>0.) then
	  GASS=PGASS * MAX(0.3,MIN(evaptv_svc(i)/evaptpv_svc(i),1.))
	  else
	  GASS=PGASS
	  end if
				 !debug: 0.3 is no proven/theoretical break point!!!

    
    !>>>respiration
      wrt=CROP1(16,i_subas,lu_counter,tc_counter,i) !organ dry weight in g/m2
	  wst=CROP1(17,i_subas,lu_counter,tc_counter,i)
	  wlv=CROP1(18,i_subas,lu_counter,tc_counter,i)
	  wso=CROP1(19,i_subas,lu_counter,tc_counter,i)
	  call getparam(fr,CROP1(7,i_subas,lu_counter,tc_counter,i),FRTB,10) !fraction of plant of each organ
	  call getparam(fl,CROP1(7,i_subas,lu_counter,tc_counter,i),FLTB,10)
	  call getparam(fs,CROP1(7,i_subas,lu_counter,tc_counter,i),FSTB,10)
	  call getparam(fo,CROP1(7,i_subas,lu_counter,tc_counter,i),FOTB,10)
	  
			!>check for partitioning summing to 1
			IF (fr+(fl+fs+fo)*(1.-fr)<0.990 .OR. fr+(fl+fs+fo)*(1.-fr)>1.001 ) THEN
				fl=fl/(fl+fs+fo)
				fs=fs/(fl+fs+fo)
				fo=fo/(fl+fs+fo)
			END IF
	
	  rmres = (RMR*wrt+RML*wlv+RMS*wst+RMO*wso) !reference maintenance requirements RM in g(CH2O)*g-1(DM)*d-1
	  teff  = Q10**((mTEMP-25.)/10.)		!Q10, RMR, RML, RMS, RMO are gained from cropfile
	  !!conrad: debug!! wTEMP-30. instead of 25. >> check WATPRO for parameterization
	  rmres = rmres*teff
	  mres  = MIN(gass,rmres)
	  
	  IF (CROP1(7,i_subas,lu_counter,tc_counter,i)>0.3) THEN !debug conrad: respiration only after emerging and initial development
	  asrc  = gass-mres                         !update assimilation minus respiration
	  											!net assimilation rate asrc
	  ELSE
	  asrc  = gass
	  END IF
	  											
    !>>>dry matter partitioning and growth respiration
	  cvf   = 1./((fl/cvl+fs/cvs+fo/cvo)*(1.-fr)+fr/cvr)
	  dmi   = cvf*asrc                          !gross dry matter growth rate dmi
	  admi = (1.0-fr)*dmi						!gross dry matter growth rate above soil
	  
	  !>leaves
	  grlv  = fl*admi							!weight of new leaves
	  dslv1 = wlv*(1-(evaptv_svc(i)/evaptpv_svc(i)))*PERDL !death due to water stress
	  laicr = 3.2/kdiftb(2,1) !critical lai for light extinction
	  dslv2 = 0.03*wlv*MAX(0.,MIN(1.,((CROP1(9,i_subas,lu_counter,tc_counter,i)-laicr)/laicr)))

	  IF (CROP1(7,i_subas,lu_counter,tc_counter,i)>0.3) THEN !debug conrad: leave death takes only place after initial development
	  dslv  = MAX(dslv1,dslv2) !use maximum of combined effects
	  ELSE
	  dslv=0.
	  END IF


	  fysdel= MAX(0.,(temp(d,muni)-TBASE)/(35-TBASE)) !leave aging
	  !aging of leaves will be excluded for now!
	  call getparam(slat,CROP1(7,i_subas,lu_counter,tc_counter,i),SLATB,6) !specific leaf area (ha/kg)
	  slat=slat*10. !*10. convert ha/kg into m2/g
					 
	  dteff  = max(0.0,temp(d,muni)-tbase)
	   
	  if (CROP1(9,i_subas,lu_counter,tc_counter,i)<6.0) then
       
        glaiex = CROP1(9,i_subas,lu_counter,tc_counter,i)*(exp(RGRLAI*dteff)-1.)	!> increase in leaf area during exponential growth
        !debug conrad: maximal growth per day - independent of existing LAI
		if (glaiex>0.2) glaiex=0.2 !clumsy workaround for far too large lai increase

		glasol = grlv*slat  	 	   !> source-limited increase in leaf area
        gla    = min(glaiex,glasol)    ! actual increase is determined by lowest value
        if ((CROP1(9,i_subas,lu_counter,tc_counter,i)+glaiex)<0.3.AND.CROP1(7,i_subas,lu_counter,tc_counter,i)<0.1) then
		   gla=glaiex
		elseif ((CROP1(9,i_subas,lu_counter,tc_counter,i)+glaiex/2)<0.85.AND.CROP1(7,i_subas,lu_counter,tc_counter,i)<0.3) then
		   gla=max(glaiex/2,gla)
		end if								! exponential growth until LAI=1 or dev=0.3
		
		if (gla==glaiex) slat = gla/grlv    ! slat will be modified in case gla equals glaiex >> grlv*slat=grlv*gla/grlv=gla=glaiex
											! original WOFOST: if (grlv.gt.0.0) here ! I have no clue why!!! Now this should work as it is consistent w/ theory behind
		if (gla==glaiex/2) slat=gla/(grlv*2)
	  end if
      !>leave mass update
	  CROP1(18,i_subas,lu_counter,tc_counter,i)=(wlv+grlv-dslv)	!this is a simplified method summing all leave cohorts in wlv and adding new built mass and subtracting death mass
      							!check if really working! stored as kg/ha
      							!leave weight is updated with growth and death matter
      
	  !>>>LAI update
      CROP1(9,i_subas,lu_counter,tc_counter,i)=CROP1(9,i_subas,lu_counter,tc_counter,i)+(grlv-dslv)*slat !update LAI with growth rate depending on existing LAI
	  !update with photoactive stem/pod area neglected because iszero in paramerterisation
	  
		!conrad debug - check for specific maximum LAI increase and place max at 6.0
		!avoid further trouble here:
		if (CROP1(9,i_subas,lu_counter,tc_counter,i)>8.0.OR.isnan(CROP1(9,i_subas,lu_counter,tc_counter,i)).OR.CROP1(9,i_subas,lu_counter,tc_counter,i)<0.) then
		write(*,*)'PROBLEM w/ LAI'
		end if

      !>roots
      grrt = fr*dmi
      call getparam(rdrr,CROP1(7,i_subas,lu_counter,tc_counter,i),RDRRTB,6)
      drrt = wrt*rdrr			!death rate of roots applied
      CROP1(16,i_subas,lu_counter,tc_counter,i)=(wrt+grrt-drrt) !root weight is updated
      
      !>stem
      grst = fs*admi
      call getparam(rdrs,CROP1(7,i_subas,lu_counter,tc_counter,i),RDRSTB,6)
      drst = wst*rdrs			!death rate of stem applied
      CROP1(17,i_subas,lu_counter,tc_counter,i)=(wst+grst-drst) !stem weight updated
      
	  IF (CROP1(14,i_subas,lu_counter,tc_counter,i)==2.) THEN !update growth in growing period only
	  CROP1(8,i_subas,lu_counter,tc_counter,i)=CROP1(8,i_subas,lu_counter,tc_counter,i)+(GROWMX*1.2*(tempeff/TSUM1)*10)*(asrc/PGASS) !height in mm
	  if (CROP1(8,i_subas,lu_counter,tc_counter,i)>GROWMX) CROP1(8,i_subas,lu_counter,tc_counter,i)=GROWMX !clumsy workaround for exceeding growth
	  END IF

      !>storage organs
      gwso = fo*admi
	  !conrad: debug
!		IF (isnan(gwso).OR.isnan(wso).OR.(wso+gwso)>200.) THEN
!			write(*,*)'trouble with organ development'
!		END IF

      CROP1(19,i_subas,lu_counter,tc_counter,i)=(wso+gwso)
      
    
    !>>>ROOTING DEPTH update
    rr 		    = min(RDMCR-CROP1(10,i_subas,lu_counter,tc_counter,i),fr*RRI)
    CROP1(10,i_subas,lu_counter,tc_counter,i) = CROP1(10,i_subas,lu_counter,tc_counter,i)+rr
    !>>>HEIGHT update done already at beginning of if statement
  
  
  END IF !end of different stage treatment
END IF !end if of stage>0

!debug conrad!
IF (i_subas==6.AND.lu_counter==2.AND.tc_counter==1.AND.i==1) THEN
!	write(*,*)'wake up - showtime!'
cropout(d,1)=CROP1(5,i_subas,lu_counter,tc_counter,i)
cropout(d,2)=CROP1(7,i_subas,lu_counter,tc_counter,i)
cropout(d,3)=CROP1(8,i_subas,lu_counter,tc_counter,i)
cropout(d,4)=CROP1(9,i_subas,lu_counter,tc_counter,i)
cropout(d,5)=CROP1(10,i_subas,lu_counter,tc_counter,i)
cropout(d,6)=CROP1(19,i_subas,lu_counter,tc_counter,i)
END IF

!check stage fulfillment
IF (CROP1(14,i_subas,lu_counter,tc_counter,i)==1.) THEN
TSUM=TSUMEM
ELSE IF (CROP1(14,i_subas,lu_counter,tc_counter,i)==2.) THEN
TSUM=TSUM1+TSUMEM
ELSE IF (CROP1(14,i_subas,lu_counter,tc_counter,i)==3.) THEN
TSUM=TSUM2+TSUM1+TSUMEM
END IF

IF (TSUM<CROP1(15,i_subas,lu_counter,tc_counter,i).AND.CROP1(14,i_subas,lu_counter,tc_counter,i)==1.) THEN !emerge!
   CROP1(14,i_subas,lu_counter,tc_counter,i)   = CROP1(14,i_subas,lu_counter,tc_counter,i)+1.
   CROP1(9,i_subas,lu_counter,tc_counter,i)    = LAIEM
   CROP1(21,i_subas,lu_counter,tc_counter,i)   = LAIEM
   TDWI=TDWI*1000./10000. !convert kg/ha into g/m2
   CROP1(16,i_subas,lu_counter,tc_counter,i)   = TDWI*FRTB(2,1)
   CROP1(17,i_subas,lu_counter,tc_counter,i)   = TDWI*(1-FRTB(2,1))*FSTB(2,1)
   CROP1(18,i_subas,lu_counter,tc_counter,i)   = TDWI*(1-FRTB(2,1))*FLTB(2,1)
   CROP1(19,i_subas,lu_counter,tc_counter,i)   = TDWI*(1-FRTB(2,1))*FOTB(2,1)
   CROP1(10,i_subas,lu_counter,tc_counter,i)   = RDI
   CROP1(7,i_subas,lu_counter,tc_counter,i)    = 0. !reset development because it will be considered for vegetative stage 0..1 and maturity stage 1..2 from now on
ELSE IF (TSUM<CROP1(15,i_subas,lu_counter,tc_counter,i)) THEN
	IF (CROP1(14,i_subas,lu_counter,tc_counter,i)==2.) THEN
		CROP1(14,i_subas,lu_counter,tc_counter,i)=CROP1(14,i_subas,lu_counter,tc_counter,i)+1.
	ELSE IF (CROP1(14,i_subas,lu_counter,tc_counter,i)==3.) THEN !harvest because of stage fulfillmet
		CROP1(13,i_subas,lu_counter,tc_counter,i)=CROP1(19,i_subas,lu_counter,tc_counter,i) !shift dry weight storage organs to harvest
		CROP1(19,i_subas,lu_counter,tc_counter,i)=0.
		CROP1(14,i_subas,lu_counter,tc_counter,i)=9. !control for next cropping possible in cropcontrol
	END IF
ELSE IF (CROP1(7,i_subas,lu_counter,tc_counter,i)>=2.) THEN !harvest because of finished development
		CROP1(13,i_subas,lu_counter,tc_counter,i)=CROP1(19,i_subas,lu_counter,tc_counter,i) !shift dry weight storage organs to harvest
		CROP1(19,i_subas,lu_counter,tc_counter,i)=0.
		CROP1(14,i_subas,lu_counter,tc_counter,i)=9. !control for next cropping possible in cropcontrol
END IF

END DO !and loop through all svcs in tc

RETURN
END SUBROUTINE CROPDEVELOP

