%wasa interpretation
%tool for data visualization of wasa output
%use with files generated in lump and wasa

%conrad jackisch, october 2006, jackisch@uni-potsdam.de

clear
%get input files:
lump_dir='../LUMP_now/';   %directory that holds lump files (end with slash)
wasa_dir='u:/conrad/wasa_now/';   %directory that holds wasa files (end with slash)

SUBfile=[lump_dir 'subbas_lump.asc']; %file containing subbasin grid
LUfile=[lump_dir 'lus_LUMP1.asc']; %file containing landscape-unit grid - check for correct run name (here: LUMP1) 
TCfile=[lump_dir 'lucontainstc.dat']; %file containing tc information (not spatially explicit)
DEMfile=[lump_dir 'demint.asc']; %file containing dem

THETAfile=[wasa_dir 'output/daily_theta.out']; %file containing daily theta for each sub mm
Tfile=[wasa_dir 'input/Time_series/temperature.dat']; %file containing daily temperature for all subs
aETPfile=[wasa_dir 'output/daily_actetranspiration.out']; %file containing daily actETP for all subs mm/d
DISfile=[wasa_dir 'output/River_Flow.out']; %file containing daily river flow for all subs m3/s
PRECfile=[wasa_dir 'input/Time_series/rain_daily.dat']; %file containing daily precipitation for all subs

%these files need to be prepared before
GAUGEfile=[lump_dir 'disgauge.dat']; %file containing daily discharge from whole basin
SUBSfile=[lump_dir 'subs.dat']; %file containing areas of all subbasins

%additional data
pETPfile=[wasa_dir 'output/daily_potetranspiration.out']; %file containing daily potential ETP for all subs mm/d
SUBROfile=[wasa_dir 'output/daily_subsurface_runoff.out']; %file containing daily subsurface runoff for all subs m3/d
QHORTfile=[wasa_dir 'output/daily_qhorton.out']; %file containing daily horton run off for all subs m3/d
OVERLANDfile=[wasa_dir 'output/daily_total_overlandflow.out']; %daily overland flow for all subs m3
WATER1file=[wasa_dir 'output/daily_water_subbasin.out']; %river flow at subbasin m3/s
WATER2file=[wasa_dir 'output/daily_water_subbasin2.out']; %river flow at subbasin m3
DEEPGWfile=[wasa_dir 'output/deep_gw.out']; %deep groundwater
RIVERSTOREfile=[wasa_dir 'output/River_Storage.out']; %river storage at each sub m3/d

%switch on/off in code
%%%%%%%%%%%%%%%%%%%%%read files%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
SUB=textread(SUBfile,'','headerlines',6);%subbasin map
SUBS=textread(SUBSfile,'','headerlines',2);%subbasin areas in km2
LU=textread(LUfile,'','headerlines',6);%lu map
TC=textread(TCfile,'','headerlines',1);%lu_id	tc_id	fraction	position
theta=textread(THETAfile,'','headerlines',2);%theta: first line are IDs, first columns are date
T=textread(Tfile,'','headerlines',2);%temperature: first 2 lines are IDs, first 2 columns are date
PREC=textread(PRECfile,'','headerlines',2);%precipitation: first 2 lines are IDs, first 2 columns are date
aETP=textread(aETPfile,'','headerlines',2);%ETP: first 2 lines are IDs, first 2 columns are date
DIS=textread(DISfile,'','headerlines',2);%discharge: first 2 lines are IDs, first 2 columns are date; river flow m3/d for each sub
DEM=textread(DEMfile,'','headerlines',6);%dem map
GAUGE=textread(GAUGEfile,'','headerlines',1);%measured discharge from whole basin, day, month, year, hight, discharge [m3/d]
DEEPGW=textread(DEEPGWfile,'','headerlines',2);%deep groundwater percolation m3/d
%pETP=textread(pETPfile,'','headerlines',2);%pETP: first 2 lines are IDs, first 2 columns are date
SUBRO=textread(SUBROfile,'','headerlines',2);%subsurface run-off: first 2 lines are IDs, first 2 columns are date
QHORT=textread(QHORTfile,'','headerlines',2);%horton overland flow: first 2 lines are IDs, first 2 columns are date
OVERLAND=textread(OVERLANDfile,'','headerlines',2);


%%%%%%%%%% CONVERSIONS FOR WATER BALANCE %%%%%%%%%%%%%%%%%%%
for j=1:length(theta(:,1)) %loop through simulated days
	thetaV(j,1)=datenum([DIS(j,1) 1 1])+DIS(j,2)-1; %get date code
    aETPV(j,1)=thetaV(j,1);
    precV(j,1)=thetaV(j,1);
	for i=1:length(SUBS(:,1)) %loop through subbasins
		thetaV(j,i+1)=theta(j,i+2)*SUBS(i,2)*1000.; %convert mm into m3 for each day and each sub
		aETPV(j,i+1)=aETP(j,i+2)*SUBS(i,2)*1000.; %convert mm into m3
		if j==length(theta(:,1))
            precV(j,i+1)=PREC(j,i+2)*SUBS(i,2)*1000.;
        else precV(j,i+1)=PREC(j+1,i+2)*SUBS(i,2)*1000.; %convert mm into m3
        end
    end
end

% output file
% fid=fopen('thetaV.dat','w+');
% dumstr=['Date   SUBs'];
% fprintf(fid,'%s\n',dumstr);
% for j=1:length(DIS(:,1))
%     fprintf(fid,'%s %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f\n',datestr(thetaV(j,1)),thetaV(j,2:(length(SUBS(:,1))+1)));
% end
% fclose(fid);
% 
% fid=fopen('aETPV.dat','w+');
% dumstr=['Date   SUBs'];
% fprintf(fid,'%s\n',dumstr);
% for j=1:length(DIS(:,1))
%     fprintf(fid,'%s %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f\n',datestr(aETPV(j,1)),aETPV(j,2:(length(SUBS(:,1))+1)));
% end
% fclose(fid);
% 
% fid=fopen('precV.dat','w+');
% dumstr=['Date   SUBs'];
% fprintf(fid,'%s\n',dumstr);
% for j=1:length(DIS(:,1))
%     fprintf(fid,'%s %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f %6.2f\n',datestr(precV(j,1)),precV(j,2:(length(SUBS(:,1))+1)));
% end
% fclose(fid);

soilwaters=zeros(1,length(DIS(:,1)));
soilwater=zeros(1,length(DIS(:,1)));
evapwater=zeros(1,length(DIS(:,1)));
rainwater=zeros(1,length(DIS(:,1)));
hortonwater=zeros(1,length(DIS(:,1))); 
subsurfwater=zeros(1,length(DIS(:,1)));
overlandwater=zeros(1,length(DIS(:,1)));
balance1=zeros(1,length(DIS(:,1)));
balance2=zeros(1,length(DIS(:,1)));

%%%%%%%%%%% WATER BALANCE %%%%%%%%%%%%%%%%%
for j=1:length(aETP(:,1)) %loop through days and sum up all subbasins
    soilwaters(j)=sum(thetaV(j,2:(length(SUBS(:,1))+1)));
    if j==1
        soilwater(j)=sum(thetaV(j,2:(length(SUBS(:,1))+1)));
    else soilwater(j)=sum(thetaV(j,2:(length(SUBS(:,1))+1)))-soilwaters(j-1);
    end
    evapwater(j)=sum(aETPV(j,2:(length(SUBS(:,1))+1)));
    rainwater(j)=sum(precV(j,2:(length(SUBS(:,1))+1)));
    hortonwater(j)=sum(QHORT(j,3:(length(SUBS(:,1))+2))); 
    subsurfwater(j)=sum(SUBRO(j,3:(length(SUBS(:,1))+2)));
    overlandwater(j)=sum(OVERLAND(j,3:(length(SUBS(:,1))+2)));
    balance1(j)=soilwater(j)+evapwater(j)+hortonwater(j)+subsurfwater(j);
    balance2(j)=soilwater(j)+evapwater(j)+hortonwater(j);
end

figure(1)
hold off
subplot(2,1,1)
plot(soilwater,'Color','red','LineWidth',1)
xlabel(['days as of ' datestr(thetaV(1,1))])
ylabel('water in m3')
title('WASA Simulation of Mod River Catchment')
hold on
plot(evapwater,'Color','green','LineWidth',1)
plot(rainwater,'Color','blue','LineWidth',1)
plot(hortonwater,'Color','yellow','LineWidth',1)
plot(subsurfwater,'Color','black','LineWidth',1)
plot(soilwaters,'Color','red','LineWidth',1)
%plot(balance2,'Color','magenta','LineWidth',2)

subplot(2,1,2)
Gtemp=zeros(1,182+length(GAUGE(:,5)));
Gtemp(182:(181+length(GAUGE(:,5))))=GAUGE(:,5);
plot(Gtemp,'Color','blue','LineWidth',1)
hold on
for i=1:length(DIS(:,1))
    distemp(i)=DIS(i,length(DIS(1,:)))+((subsurfwater(i)/520000000)*86400);
end
plot(distemp,'Color','green','LineWidth',1)
plot(DIS(:,length(DIS(1,:))),'Color','red','LineWidth',1)

for i=2:3
    x=int8(rand(1)*(length(DIS(1,:))-2));
figure(i)
hold off
subplot(3,1,1)
hold off
plot(precV(:,x+1),'Color','blue','LineWidth',1)
xlabel(['days as of ' datestr(thetaV(1,1)) 'blue:prec red:theta'])
ylabel('water in m3')
title(['WASA Simulation of Mod River Catchment - SUBBASIN ' num2str(x)])
hold on
plot(thetaV(:,x+1),'Color','red','LineWidth',1)

subplot(3,1,2)
hold off
plot(aETPV(:,x+1),'Color','red','LineWidth',1)
xlabel(['days as of ' datestr(thetaV(1,1)) 'yellow:sub_RO red:etp_act'])
ylabel('water in m3')
hold on
plot(SUBRO(:,x+2),'Color','yellow','LineWidth',1)

subplot(3,1,3)
hold off
plot(QHORT(:,x+2),'Color','black','LineWidth',1)
xlabel(['days as of ' datestr(thetaV(1,1)) 'black:Qhorton red:dWater'])
ylabel('water in m3')
hold on
for j=2:length(theta(:,1))
   dtheta_dummy(j)=theta(j,x+2)-theta(j-1,x+2);
end
plot(dtheta_dummy,'Color','red','LineWidth',1)
end
